//rpldslp.h:

/*
 *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2009-2012
 *
 *  This file is part of RoarAudio PlayList Daemon,
 *  a playlist management daemon for RoarAudio.
 *  See README for details.
 *
 *  This file is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License version 3
 *  as published by the Free Software Foundation.
 *
 *  RoarAudio is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this software; see the file COPYING.  If not, write to
 *  the Free Software Foundation, 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 *
 */

#ifndef _RPLD_SLP_H_
#define _RPLD_SLP_H_

#define RPLD_SLP_TYPE_RPLD       "service:playlist.fellig:rpld"
#define RPLD_SLP_TYPE_RPLD_LEN   28

#ifdef ROAR_HAVE_LIBSLP
void register_slp_callback(SLPHandle hslp, SLPError errcode, void * cookie);
int register_slp (int unreg, const char * sockname);
#endif

#endif

//ll
